@@ -173,14 +173,16 @@ this.htCriticalPoints =  new java.util.Hashtable ();
 this.asc.setModelInfoForSet ("criticalPoints", this.htCriticalPoints, 0);
 }this.discardLinesUntilContains ("X(");
 var f = (this.line.indexOf ("AU") >= 0 ? 0.5291772 : 1);
+var offset = (this.line.indexOf ("CP N.") >= 0 ? 6 : 0);
 this.discardLinesUntilContains ("**");
 for (var i = 1; i <= n; i++) {
 if (isTLAP) {
 if (this.rd ().indexOf ("***") >= 0) break;
 }this.discardLinesUntilContains (",");
-var tokens = JU.PT.getTokens (JU.PT.rep (isTLAP ? this.line : this.line.substring (this.line.indexOf (")") + 1), "-999.999", " -999.999"));
+var tokens = JU.PT.getTokens (JU.PT.rep (JU.PT.rep (this.line.substring (offset), "-", " -"), ", -", ",-"));
 var pt = JU.P3.new3 (f * this.parseFloatStr (tokens[0]), f * this.parseFloatStr (tokens[1]), f * this.parseFloatStr (tokens[2]));
 var type = null;
+System.out.println (tokens[3] + " " + pt + " " + this.line);
 switch ("-3,-1,+1,+3".indexOf (tokens[3].substring (3, 5))) {
 case 0:
 type = "nuclei";
